pub struct NotBefore(pub NumericDate);Expand description
Not Before (nbf) claim.
Time before which the JWT MUST NOT be accepted for processing. The
processing of the nbf claim requires that the current date/time MUST
be after or equal to the not-before date/time listed in the “nbf” claim.
Implementers MAY provide for some small leeway, usually no more than a
few minutes, to account for clock skew.
Tuple Fields
0: NumericDateImplementations